#!/usr/bin/python3


from .Color import Color
from .ColorSpectrum import ColorSpectrum
from .CSSMap import CSSMap

from .HTMLElement import HTMLElement
from .HTMLRawText import HTMLRawText
from .HTML5RootElement import HTML5RootElement

from .HTML5Scope import HTML5Scope



__version__ = "0.2019.9.11"


